@@ -1,7 +1,12 @@
+import logging
+
 from concurrent_tasks.background import BackgroundTask
 from concurrent_tasks.restartable import RestartableTask
 from concurrent_tasks.thread_safe_pool import ThreadSafeTaskPool
 from concurrent_tasks.threaded_pool import (
     AsyncThreadedTaskPool,
     BlockingThreadedTaskPool,
+    ThreadedPoolContextManagerWrapper,
 )
+
+logging.getLogger(__name__).addHandler(logging.NullHandler())
